import { 
  select, 
  csv,
	scaleBand,
  scaleLinear,
	max,
	axisBottom,
	axisLeft,
	format } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.country;
  const yValue = d => d.immigrants_prop;
  const margin = {top: 50, right: 20, bottom: 40, left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.padding(0.1);
  
  const yScale = scaleLinear()
  	.domain([0, max(data, d => d.immigrants_prop)])
  	.range([0, innerHeight].reverse());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(format(".0%"))
  	.tickSize(-innerWidth);
  
  const xAxis = axisBottom(xScale);
  
  g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`)
  	.selectAll('.domain, .tick line')
  		.remove();
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.text('Percentage')
  	.attr('class', 'y-label')
  	.attr('x', -innerHeight / 2)
  	.attr('text-anchor', 'middle')
  	.attr('y', -60);
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('x', d => xScale(xValue(d)))
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', d => xScale.bandwidth())
  	.attr('height', d => innerHeight - yScale(yValue(d)));
  
  g.append('text')
  	.text('Percentange of foreign-born population')
  	.attr('y', -10)
  	.attr('class', 'title');
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.immigrants_prop = +d.immigrants_prop / 100;
  })
	render(data)
});






















